@@ -44,15 +44,21 @@ class ManageFiles():
         try:
             url = f"http://{self.fms_url}/{file_key}"
             file_location = os.path.join(base_path,f"{file_name}.{file_extention}")
-            headers = {'x-ext': file_extention, 'x-group': group, 'x-createdby': created_by}
+            headers = {'content-type': 'application/octet-stream',
+                        'x-ext': file_extention, 'x-group': group, 'x-createdby': created_by}
             file_size = os.path.getsize(file_location)
-            with open(file_location, 'rb') as file:
-                with requests.post(url, headers=headers, data=file, stream=True) as req:
-                    for chunk in tqdm(req.iter_content(chunk_size=4096),total=file_size,unit='B', unit_scale=True, unit_divisor=1024):
-                        pass
+            with open(file_location, 'rb') as file:                
+                with requests.post(url, file, headers=headers, stream=True) as req:
+                    req.raise_for_status()
+                    with tqdm(total=file_size, unit='B', unit_scale=True, unit_divisor=1024,
+                            desc=f"Uploading {file_name}.{file_extention}") as pbar:
+                        for chunk in req.iter_content(chunk_size=4096):
+                            pbar.update(len(chunk))
+                            
             return "File Uploaded Successfully", True
         except Exception as err:
-            return err, False
+            response = err
+            return response, False
 
     def delete_file(self, file_key, ext, base_path): 
         os.remove(os.path.join(base_path,f"{file_key}.{ext}"))
